<?php

declare(strict_types=1);

namespace Drupal\plugin_config_form_builder_test\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a Plugin config form builder form.
 */
final class PluginConfigForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'plugin_config_form_builder_plugin_form_test';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['enable'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable plugin config'),
      '#default_value' => TRUE,
    ];

    $form['plugin_config'] = [
      '#type' => 'plugin_config',
      '#title' => $this->t('Plugin config'),
      '#plugin_manager' => 'plugin.manager.condition',
      '#default_value' => [
        '31c7680f-7d0d-40a5-8e0b-18e131c0ef77' => [
          'id' => 'current_theme',
          'theme' => 'claro',
          'negate' => TRUE,
        ],
        '31c7680f-7d0d-40a5-8e0b-18e131c0ef78' => [
          'id' => 'current_theme',
          'theme' => 'olivero',
          'negate' => FALSE,
        ],
      ],
      '#vertical_tabs' => TRUE,
      '#cardinality' => 4,
    ];
    $form['plugin_config']['#states'] = [
      'visible' => [':input[name="enable"]' => ['checked' => TRUE]],
    ];

    $form['actions'] = [
      '#type' => 'actions',
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Send'),
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state): void {
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $form_state->cleanValues();
    if (function_exists('dpm')) {
      dpm($form_state->getValue('plugin_config'));
    }
    else {
      $this->messenger()->addMessage(print_r($form_state->getValue('plugin_config'), TRUE));
    }

    \Drupal::state()->set('plugin_config_form_builder_plugin_form_test', $form_state->getValue('plugin_config'));
  }

}
