<?php

declare(strict_types=1);

namespace Drupal\plugin_config_form_builder_test\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a Plugin config form builder form.
 */
final class PluginForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'plugin_config_form_builder_plugin_form_test';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['enable'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable plugin config'),
      '#default_value' => TRUE,
    ];

    $form['node_type'] = [
      '#type' => 'single_plugin_config',
      '#title' => $this->t('Node type condition'),
      '#plugin_manager' => 'plugin.manager.condition',
      '#default_value' => [
        'id' => 'entity_bundle:node',
      ],
    ];

    $form['node_type']['#states'] = [
      'visible' => [':input[name="enable"]' => ['checked' => TRUE]],
    ];

    $form['user_role'] = [
      '#type' => 'single_plugin_config',
      '#title' => $this->t('User role condition'),
      '#plugin_manager' => 'plugin.manager.condition',
      '#default_value' => [
        'id' => 'user_role',
      ],
    ];


    $form['actions'] = [
      '#type' => 'actions',
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Send'),
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state): void {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $form_state->cleanValues();
    
    if (function_exists('dpm')) {
      dpm($form_state->getValue('node_type'));
      dpm($form_state->getValue('user_role'));
    }
    else {
      $this->messenger()->addMessage(print_r($form_state->getValue('node_type'), TRUE));
      $this->messenger()->addMessage(print_r($form_state->getValue('user_role'), TRUE));
    }

  }

}
