<?php

declare(strict_types=1);

namespace Drupal\plugin_config_form_builder_test\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a Plugin config form builder form.
 */
final class PluginSelectForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'plugin_config_form_builder_plugin_form_test';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['enable'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable plugin select'),
      '#default_value' => TRUE,
    ];

    $form['plugin_select'] = [
      '#type' => 'plugin_select',
      '#title' => $this->t('Plugin select'),
      '#plugin_manager' => 'plugin.manager.condition',
      '#configuration' => TRUE,
      '#default_value' => [
        'plugin_id' => 'current_theme',
        'configuration' => [
          'theme' => 'stable9',
          'negate' => TRUE,
        ]
      ],
    ];

    $form['plugin_select']['#states'] = [
      'visible' => [':input[name="enable"]' => ['checked' => TRUE]],
    ];

    $form['actions'] = [
      '#type' => 'actions',
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Send'),
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state): void {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    dpm($form_state->getValue('plugin_select'));
  }

}
