<?php

namespace Drupal\plugin_config_form_builder\Element;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Plugin\PluginManagerInterface;
use Drupal\Core\Render\Attribute\FormElement;
use Drupal\Core\Render\Element\FormElementBase;

/**
 * Provides a plugin_select element.
 */
#[FormElement('plugin_select')]
class PluginSelect extends FormElementBase {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    $class = static::class;
    return [
      '#input' => TRUE,
      '#process' => [
        [$class, 'processPlugin'],
      ],
      '#theme_wrappers' => ['container'],
    ];
  }


  /**
   * Expands the element.
   */
  public static function processPlugin(&$element, FormStateInterface $form_state, &$complete_form) {
    /** @var PluginManagerInterface $plugin_manager */
    $plugin_manager = \Drupal::service($element['#plugin_manager']);
    $options = array_map(function($d) {return $d['label'];}, $plugin_manager->getDefinitions());

    $wrapper = 'plugin-select-' . ($element['#uuid'] ?? 'no');
    $element += [
      '#type' => 'fieldset',
      '#collapsible' => FALSE,
      '#prefix' => '<div id="' . $element['#id'] . '-wrapper">',
      '#suffix' => '</div>',
    ];
    $element['#tree'] = TRUE;
    $element['id'] = [
      '#type' => 'select',
      '#title' => t('Plugin'),
      '#options' => $options,
      '#default_value' => $element['#default_value']['id'] ?? '',
    ];
    $element['plugin'] = [
      '#prefix' => '<div id="'.$wrapper.'">',
      '#suffix' => '</div>',
    ];

    if ($element['#configuration'] ?? FALSE) {
      $element['plugin_id']['#ajax'] = [
        'callback' => self::class . '::pluginSelect',
        'wrapper' => $wrapper,
      ];
      if ($plugin_id = $form_state->getValue($element['#parents']) && !empty($form_state->getValue($element['#parents'])['plugin_id']) ? $form_state->getValue($element['#parents'])['plugin_id'] : $element['#default_value']['plugin_id']) {
        $element += [
          '#type' => 'single_plugin_config',
          '#title' => t('Configuration'),
          '#plugin_manager' => $element['#plugin_manager'],
          '#default_value' => [
            'plugin_id' => $plugin_id,
            'configuration' => $element['#default_value']['configuration'],
          ],
        ];
      }
    }


    return $element;
  }

  public static function pluginSelect($form, FormStateInterface $form_state) {
    $triggering_element = $form_state->getTriggeringElement();
    $parents = array_slice($triggering_element['#parents'], 0, -1);
    foreach ($parents as $parent) {
      $form = $form[$parent];
    }
    return $form['plugin'];
  }

  /**
   * {@inheritdoc}
   */
  public static function valueCallback(&$element, $input, FormStateInterface $form_state) {
    if ($input) {
      $plugin_manager = \Drupal::service($element['#plugin_manager']);
      $instance = $plugin_manager->createInstance($input['id'], $input);
      $default_configuration = $instance->getConfiguration() + $instance->defaultConfiguration();
      return $default_configuration;
    }

    return $input ?? [];
  }

}
