<?php

namespace Drupal\Tests\spa\FunctionalJavascript;

use Drupal\Core\Url;
use Drupal\FunctionalJavascriptTests\WebDriverTestBase;

/**
 * Plugin config form builder regression tests.
 *
 * @group plugin_config_form_builder
 */
class PluginConfigFormTest extends WebDriverTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'plugin_config_form_builder',
    'plugin_config_form_builder_test',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
  }

  public function testPluginConfigForm() {
    // @todo: Switch to non admin
    $this->drupalLogin($this->rootUser);
    $this->drupalGet(Url::fromRoute('plugin_config_form_builder_test.plugin_config_form_test'));

    // Smoke test
    $this->assertSession()->pageTextContains('Plugin Config Form Test');

    // Basic settings.
    $page = $this->getSession()->getPage();
    $page->selectFieldOption('plugin_config[new_plugin][id]', 'user_role');
    sleep(2);

    // Add an argument
    $page->pressButton('Add plugin');
    sleep(1);

    $uuids = $this->getUUIDs('plugin_config');
    $this->assertSession()->pageTextContains('User Role');

    self::assertCount(3, $uuids);
    $uuid = $uuids[2];
    $tab = $page->find('css', '[href^="#edit-plugin-config-'.$uuid.'"]');
    $tab->click();
    $checkbox = $page->find('css', '[name="plugin_config['.$uuid.'][roles][authenticated]"]');
    if ($checkbox) {
      $checkbox->click();
    }

    // Add one more plugin
    $page->pressButton('Add plugin');
    sleep(1);
    $uuids = $this->getUUIDs('plugin_config');
    self::assertCount(4, $uuids);

    // Test if we can remove a plugin
    $uuid = $uuids[1];
    $tab = $page->find('css', '[href^="#edit-plugin-config-'.$uuid.'"]');
    $tab->click();
    $page->find('css', '[name="remove-plugin-'.$uuid.'"]')->click();
    sleep(1);
    $uuids = $this->getUUIDs('plugin_config');
    self::assertCount(3, $uuids);

    // Test if we save correctly
    $page->find('css', '[value="Send"]')->click();
    sleep(3);
    $plugin_config = \Drupal::state()->get('plugin_config_form_builder_plugin_form_test', []);
    self::assertCount(3, $plugin_config);
    self::assertEquals('authenticated', $plugin_config[$uuids[1]]['roles']['authenticated']);
  }

  protected function getUUIDs($type) {
    $uuids = [];
    $page = $this->getSession()->getPage();
    foreach ($page->findAll('css', '[data-drupal-selector="edit-'.str_replace('_', '-', $type).'-plugin-group"] input') as $element) {
      $name = $element->getAttribute('name');
      $matches = [];
      if (preg_match('/'.$type.'\[([^]]*)\]\[id\]/', $name, $matches)) {
        $uuids[] = $matches[1];
      }
    }

    return $uuids;
  }
}
